@@ -13,11 +13,11 @@ Passwd::Keyring::Auto - interface to secure password storage(s)
 
 =head1 VERSION
 
-Version 0.3003
+Version 0.70
 
 =cut
 
-our $VERSION = '0.3003';
+our $VERSION = '0.70';
 
 =head1 SYNOPSIS
 
@@ -184,7 +184,7 @@ default keyring selection rules, and per-application overrides.
 
 It's initial version can be created by L<passwd_keyring> script:
 
-    passwd_keyring create-config
+    passwd_keyring config_create
 
 and edited afterwards.
 
@@ -198,7 +198,7 @@ Linux/Unix and C<~/Local Settings/Application Data/.passwd-keyring.cfg>
 on Windows (more exactly: C<.passwd-keyring.cfg> in directory reported by
 C<my_data> function from L<File::HomeDir>).
 
-Environment variable C<PASSWD_KEYRING_AUTO_CONFIG> can be used to
+Environment variable C<PASSWD_KEYRING_CONFIG> can be used to
 override this setting (and should contain path of the configuration
 file). Also, C<config> parameter can be used in C<get_keyring> method
 (and takes precedence even over env variable).
@@ -240,11 +240,11 @@ General configuration variables:
 
 =over 4
 
-=item C<PASSWD_KEYRING_AUTO_CONFIG>
+=item C<PASSWD_KEYRING_CONFIG>
 
 Defines location of the config file.
 
-=item C<PASSWD_KEYRING_AUTO_DEBUG>
+=item C<PASSWD_KEYRING_DEBUG>
 
 Log on stderr details about tried and selected backends (and errors
 faced while they are tried).
@@ -258,25 +258,25 @@ variables):
 
 =over 4
 
-=item C<PASSWD_KEYRING_AUTO_FORCE> 
+=item C<PASSWD_KEYRING_FORCE> 
 
 Use given backend and nothing else. For example, by setting
-C<PASSWD_KEYRING_AUTO_FORCE=KDEWallet> user may enforce use of
+C<PASSWD_KEYRING_FORCE=KDEWallet> user may enforce use of
 L<Passwd::Keyring::KDEWallet>.
 
 This variable is completely ignored if C<force> parameter was
 specified, and causes runtime error if specified backend is not
 present, not working, or present on the C<forbid> list.
 
-=item C<PASSWD_KEYRING_AUTO_FORBID>
+=item C<PASSWD_KEYRING_FORBID>
 
 Space separated list of backends to forbid, for example
-C<PASSWD_KEYRING_AUTO_FORBID="Gnome KDEWallet">.
+C<PASSWD_KEYRING_FORBID="Gnome KDEWallet">.
 
 Ignored if C<force> parameter was specified, otherwise works as this
 param.
 
-=item C<PASSWD_KEYRING_AUTO_PREFER> 
+=item C<PASSWD_KEYRING_PREFER> 
 
 Space separated names of backends to prefer.
 
@@ -295,7 +295,7 @@ the following places (first found is returned):
 
 =item hardcoded value (C<get_keyring> param),
 
-=item environment variable (C<PASSWD_KEYRING_AUTO_...>)
+=item environment variable (C<PASSWD_KEYRING_...>)
 
 =item configuration file per-application setting 
 
@@ -307,7 +307,7 @@ the following places (first found is returned):
 
 Each param is calculated separately, so one can have C<prefer>
 initialized from hardcoded value, C<forbid> taken from the config file
-and C<force> defined by C<PASSWD_KEYRING_AUTO_FORCE> environment
+and C<force> defined by C<PASSWD_KEYRING_FORCE> environment
 variable. This may sometimes be confusing so use sparingly (and limit
 to config file unless you really have reason to do otherwise).
 
