@@ -6,7 +6,7 @@ use namespace::clean;
 
 =head1 NAME
 
-Passwd::Keyring::Auto::Selector - actual implementation of keyring picking algorithm
+Passwd::Keyring::Auto::Chooser - actual implementation of keyring picking algorithm
 
 =head1 DESCRIPTION
 
@@ -48,7 +48,7 @@ has '_config' => (
     });
 
 has 'debug' => (is=>'lazy', builder=>sub {
-                    return $ENV{PASSWD_KEYRING_AUTO_DEBUG} ? 1 : 0;
+                    return $ENV{PASSWD_KEYRING_DEBUG} ? 1 : 0;
                 });
 
 sub get_keyring {
@@ -61,7 +61,7 @@ sub get_keyring {
     my $config = $self->_config;
 
     my $force = $self->force
-                || $ENV{PASSWD_KEYRING_AUTO_FORCE}
+                || $ENV{PASSWD_KEYRING_FORCE}
                 || $config->force($app);
 
     if($debug) {
@@ -83,11 +83,11 @@ sub get_keyring {
     #################################################################
 
     my $forbid = $self->forbid
-                 || [ split(/\s+/x, $ENV{PASSWD_KEYRING_AUTO_FORBID} 
+                 || [ split(/\s+/x, $ENV{PASSWD_KEYRING_FORBID} 
                                     || $config->forbid($app)
                                     || '') ];
     my $prefer = $self->prefer
-                 || [ split(/\s+/x, $ENV{PASSWD_KEYRING_AUTO_PREFER} 
+                 || [ split(/\s+/x, $ENV{PASSWD_KEYRING_PREFER} 
                                     || $config->prefer($app)
                                     || '') ];
 
@@ -168,7 +168,7 @@ sub get_keyring {
 
 sub _get_env {
     my ($self, $name) = @_;
-    my $full_name = "PASSWD_KEYRING_AUTO_" . $name;
+    my $full_name = "PASSWD_KEYRING_" . $name;
     if(exists $ENV{$full_name}) {
         print STDERR "[Passwd::Keyring] Found (and using) environment variable $full_name: $ENV{$full_name}\n";
         return $ENV{$full_name};
